"""_2214.py

MountableComponent
"""


from typing import Optional

from mastapy._internal import constructor
from mastapy.system_model.part_model import _2187, _2196, _2195
from mastapy.system_model.part_model.shaft_model import _2232
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.part_model.cycloidal import _2318
from mastapy.system_model.connections_and_sockets import (
    _2023, _2016, _2019, _2020,
    _2024, _2032, _2038, _2043,
    _2046, _2027, _2017, _2018,
    _2025, _2030, _2031, _2033,
    _2034, _2035, _2036, _2037,
    _2039, _2040, _2041, _2044,
    _2045
)
from mastapy.system_model.connections_and_sockets.gears import (
    _2050, _2052, _2054, _2056,
    _2058, _2060, _2062, _2064,
    _2066, _2069, _2070, _2071,
    _2074, _2076, _2078, _2080,
    _2082, _2061
)
from mastapy.system_model.connections_and_sockets.cycloidal import (
    _2086, _2089, _2092, _2084,
    _2085, _2087, _2088, _2090,
    _2091
)
from mastapy.system_model.connections_and_sockets.couplings import (
    _2093, _2095, _2097, _2099,
    _2101, _2103, _2094, _2096,
    _2098, _2100, _2102, _2104,
    _2105
)
from mastapy._internal.python_net import python_net_import

_MOUNTABLE_COMPONENT = python_net_import('SMT.MastaAPI.SystemModel.PartModel', 'MountableComponent')


__docformat__ = 'restructuredtext en'
__all__ = ('MountableComponent',)


class MountableComponent(_2195.Component):
    """MountableComponent

    This is a mastapy class.
    """

    TYPE = _MOUNTABLE_COMPONENT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'MountableComponent.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def rotation_about_axis(self) -> 'float':
        """float: 'RotationAboutAxis' is the original name of this property."""

        temp = self.wrapped.RotationAboutAxis
        return temp

    @rotation_about_axis.setter
    def rotation_about_axis(self, value: 'float'):
        self.wrapped.RotationAboutAxis = float(value) if value else 0.0

    @property
    def inner_component(self) -> '_2187.AbstractShaft':
        """AbstractShaft: 'InnerComponent' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerComponent
        if _2187.AbstractShaft.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_component to AbstractShaft. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_component_of_type_shaft(self) -> '_2232.Shaft':
        """Shaft: 'InnerComponent' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerComponent
        if _2232.Shaft.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_component to Shaft. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_component_of_type_cycloidal_disc(self) -> '_2318.CycloidalDisc':
        """CycloidalDisc: 'InnerComponent' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerComponent
        if _2318.CycloidalDisc.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_component to CycloidalDisc. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection(self) -> '_2023.Connection':
        """Connection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2023.Connection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to Connection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_abstract_shaft_to_mountable_component_connection(self) -> '_2016.AbstractShaftToMountableComponentConnection':
        """AbstractShaftToMountableComponentConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2016.AbstractShaftToMountableComponentConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to AbstractShaftToMountableComponentConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_belt_connection(self) -> '_2019.BeltConnection':
        """BeltConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2019.BeltConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to BeltConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_coaxial_connection(self) -> '_2020.CoaxialConnection':
        """CoaxialConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2020.CoaxialConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to CoaxialConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_cvt_belt_connection(self) -> '_2024.CVTBeltConnection':
        """CVTBeltConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2024.CVTBeltConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to CVTBeltConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_inter_mountable_component_connection(self) -> '_2032.InterMountableComponentConnection':
        """InterMountableComponentConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2032.InterMountableComponentConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to InterMountableComponentConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_planetary_connection(self) -> '_2038.PlanetaryConnection':
        """PlanetaryConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2038.PlanetaryConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to PlanetaryConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_rolling_ring_connection(self) -> '_2043.RollingRingConnection':
        """RollingRingConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2043.RollingRingConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to RollingRingConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_shaft_to_mountable_component_connection(self) -> '_2046.ShaftToMountableComponentConnection':
        """ShaftToMountableComponentConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2046.ShaftToMountableComponentConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to ShaftToMountableComponentConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_agma_gleason_conical_gear_mesh(self) -> '_2050.AGMAGleasonConicalGearMesh':
        """AGMAGleasonConicalGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2050.AGMAGleasonConicalGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to AGMAGleasonConicalGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_bevel_differential_gear_mesh(self) -> '_2052.BevelDifferentialGearMesh':
        """BevelDifferentialGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2052.BevelDifferentialGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to BevelDifferentialGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_bevel_gear_mesh(self) -> '_2054.BevelGearMesh':
        """BevelGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2054.BevelGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to BevelGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_concept_gear_mesh(self) -> '_2056.ConceptGearMesh':
        """ConceptGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2056.ConceptGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to ConceptGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_conical_gear_mesh(self) -> '_2058.ConicalGearMesh':
        """ConicalGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2058.ConicalGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to ConicalGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_cylindrical_gear_mesh(self) -> '_2060.CylindricalGearMesh':
        """CylindricalGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2060.CylindricalGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to CylindricalGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_face_gear_mesh(self) -> '_2062.FaceGearMesh':
        """FaceGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2062.FaceGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to FaceGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_gear_mesh(self) -> '_2064.GearMesh':
        """GearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2064.GearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to GearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_hypoid_gear_mesh(self) -> '_2066.HypoidGearMesh':
        """HypoidGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2066.HypoidGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to HypoidGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_klingelnberg_cyclo_palloid_conical_gear_mesh(self) -> '_2069.KlingelnbergCycloPalloidConicalGearMesh':
        """KlingelnbergCycloPalloidConicalGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2069.KlingelnbergCycloPalloidConicalGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to KlingelnbergCycloPalloidConicalGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_klingelnberg_cyclo_palloid_hypoid_gear_mesh(self) -> '_2070.KlingelnbergCycloPalloidHypoidGearMesh':
        """KlingelnbergCycloPalloidHypoidGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2070.KlingelnbergCycloPalloidHypoidGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to KlingelnbergCycloPalloidHypoidGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh(self) -> '_2071.KlingelnbergCycloPalloidSpiralBevelGearMesh':
        """KlingelnbergCycloPalloidSpiralBevelGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2071.KlingelnbergCycloPalloidSpiralBevelGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to KlingelnbergCycloPalloidSpiralBevelGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_spiral_bevel_gear_mesh(self) -> '_2074.SpiralBevelGearMesh':
        """SpiralBevelGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2074.SpiralBevelGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to SpiralBevelGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_straight_bevel_diff_gear_mesh(self) -> '_2076.StraightBevelDiffGearMesh':
        """StraightBevelDiffGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2076.StraightBevelDiffGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to StraightBevelDiffGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_straight_bevel_gear_mesh(self) -> '_2078.StraightBevelGearMesh':
        """StraightBevelGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2078.StraightBevelGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to StraightBevelGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_worm_gear_mesh(self) -> '_2080.WormGearMesh':
        """WormGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2080.WormGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to WormGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_zerol_bevel_gear_mesh(self) -> '_2082.ZerolBevelGearMesh':
        """ZerolBevelGearMesh: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2082.ZerolBevelGearMesh.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to ZerolBevelGearMesh. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_cycloidal_disc_central_bearing_connection(self) -> '_2086.CycloidalDiscCentralBearingConnection':
        """CycloidalDiscCentralBearingConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2086.CycloidalDiscCentralBearingConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to CycloidalDiscCentralBearingConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_cycloidal_disc_planetary_bearing_connection(self) -> '_2089.CycloidalDiscPlanetaryBearingConnection':
        """CycloidalDiscPlanetaryBearingConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2089.CycloidalDiscPlanetaryBearingConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to CycloidalDiscPlanetaryBearingConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_ring_pins_to_disc_connection(self) -> '_2092.RingPinsToDiscConnection':
        """RingPinsToDiscConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2092.RingPinsToDiscConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to RingPinsToDiscConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_clutch_connection(self) -> '_2093.ClutchConnection':
        """ClutchConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2093.ClutchConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to ClutchConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_concept_coupling_connection(self) -> '_2095.ConceptCouplingConnection':
        """ConceptCouplingConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2095.ConceptCouplingConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to ConceptCouplingConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_coupling_connection(self) -> '_2097.CouplingConnection':
        """CouplingConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2097.CouplingConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to CouplingConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_part_to_part_shear_coupling_connection(self) -> '_2099.PartToPartShearCouplingConnection':
        """PartToPartShearCouplingConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2099.PartToPartShearCouplingConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to PartToPartShearCouplingConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_spring_damper_connection(self) -> '_2101.SpringDamperConnection':
        """SpringDamperConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2101.SpringDamperConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to SpringDamperConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_connection_of_type_torque_converter_connection(self) -> '_2103.TorqueConverterConnection':
        """TorqueConverterConnection: 'InnerConnection' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerConnection
        if _2103.TorqueConverterConnection.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_connection to TorqueConverterConnection. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket(self) -> '_2027.CylindricalSocket':
        """CylindricalSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2027.CylindricalSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to CylindricalSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_bearing_inner_socket(self) -> '_2017.BearingInnerSocket':
        """BearingInnerSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2017.BearingInnerSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to BearingInnerSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_bearing_outer_socket(self) -> '_2018.BearingOuterSocket':
        """BearingOuterSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2018.BearingOuterSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to BearingOuterSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_cvt_pulley_socket(self) -> '_2025.CVTPulleySocket':
        """CVTPulleySocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2025.CVTPulleySocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to CVTPulleySocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_inner_shaft_socket(self) -> '_2030.InnerShaftSocket':
        """InnerShaftSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2030.InnerShaftSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to InnerShaftSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_inner_shaft_socket_base(self) -> '_2031.InnerShaftSocketBase':
        """InnerShaftSocketBase: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2031.InnerShaftSocketBase.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to InnerShaftSocketBase. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_mountable_component_inner_socket(self) -> '_2033.MountableComponentInnerSocket':
        """MountableComponentInnerSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2033.MountableComponentInnerSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to MountableComponentInnerSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_mountable_component_outer_socket(self) -> '_2034.MountableComponentOuterSocket':
        """MountableComponentOuterSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2034.MountableComponentOuterSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to MountableComponentOuterSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_mountable_component_socket(self) -> '_2035.MountableComponentSocket':
        """MountableComponentSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2035.MountableComponentSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to MountableComponentSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_outer_shaft_socket(self) -> '_2036.OuterShaftSocket':
        """OuterShaftSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2036.OuterShaftSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to OuterShaftSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_outer_shaft_socket_base(self) -> '_2037.OuterShaftSocketBase':
        """OuterShaftSocketBase: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2037.OuterShaftSocketBase.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to OuterShaftSocketBase. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_planetary_socket(self) -> '_2039.PlanetarySocket':
        """PlanetarySocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2039.PlanetarySocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to PlanetarySocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_planetary_socket_base(self) -> '_2040.PlanetarySocketBase':
        """PlanetarySocketBase: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2040.PlanetarySocketBase.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to PlanetarySocketBase. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_pulley_socket(self) -> '_2041.PulleySocket':
        """PulleySocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2041.PulleySocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to PulleySocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_rolling_ring_socket(self) -> '_2044.RollingRingSocket':
        """RollingRingSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2044.RollingRingSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to RollingRingSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_shaft_socket(self) -> '_2045.ShaftSocket':
        """ShaftSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2045.ShaftSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to ShaftSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_cylindrical_gear_teeth_socket(self) -> '_2061.CylindricalGearTeethSocket':
        """CylindricalGearTeethSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2061.CylindricalGearTeethSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to CylindricalGearTeethSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_cycloidal_disc_axial_left_socket(self) -> '_2084.CycloidalDiscAxialLeftSocket':
        """CycloidalDiscAxialLeftSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2084.CycloidalDiscAxialLeftSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to CycloidalDiscAxialLeftSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_cycloidal_disc_axial_right_socket(self) -> '_2085.CycloidalDiscAxialRightSocket':
        """CycloidalDiscAxialRightSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2085.CycloidalDiscAxialRightSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to CycloidalDiscAxialRightSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_cycloidal_disc_inner_socket(self) -> '_2087.CycloidalDiscInnerSocket':
        """CycloidalDiscInnerSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2087.CycloidalDiscInnerSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to CycloidalDiscInnerSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_cycloidal_disc_outer_socket(self) -> '_2088.CycloidalDiscOuterSocket':
        """CycloidalDiscOuterSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2088.CycloidalDiscOuterSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to CycloidalDiscOuterSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_cycloidal_disc_planetary_bearing_socket(self) -> '_2090.CycloidalDiscPlanetaryBearingSocket':
        """CycloidalDiscPlanetaryBearingSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2090.CycloidalDiscPlanetaryBearingSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to CycloidalDiscPlanetaryBearingSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_ring_pins_socket(self) -> '_2091.RingPinsSocket':
        """RingPinsSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2091.RingPinsSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to RingPinsSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_clutch_socket(self) -> '_2094.ClutchSocket':
        """ClutchSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2094.ClutchSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to ClutchSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_concept_coupling_socket(self) -> '_2096.ConceptCouplingSocket':
        """ConceptCouplingSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2096.ConceptCouplingSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to ConceptCouplingSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_coupling_socket(self) -> '_2098.CouplingSocket':
        """CouplingSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2098.CouplingSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to CouplingSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_part_to_part_shear_coupling_socket(self) -> '_2100.PartToPartShearCouplingSocket':
        """PartToPartShearCouplingSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2100.PartToPartShearCouplingSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to PartToPartShearCouplingSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_spring_damper_socket(self) -> '_2102.SpringDamperSocket':
        """SpringDamperSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2102.SpringDamperSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to SpringDamperSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_torque_converter_pump_socket(self) -> '_2104.TorqueConverterPumpSocket':
        """TorqueConverterPumpSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2104.TorqueConverterPumpSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to TorqueConverterPumpSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def inner_socket_of_type_torque_converter_turbine_socket(self) -> '_2105.TorqueConverterTurbineSocket':
        """TorqueConverterTurbineSocket: 'InnerSocket' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.InnerSocket
        if _2105.TorqueConverterTurbineSocket.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast inner_socket to TorqueConverterTurbineSocket. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def is_mounted(self) -> 'bool':
        """bool: 'IsMounted' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.IsMounted
        return temp

    def mount_on(self, shaft: '_2187.AbstractShaft', offset: Optional['float'] = float('nan')) -> '_2020.CoaxialConnection':
        """ 'MountOn' is the original name of this method.

        Args:
            shaft (mastapy.system_model.part_model.AbstractShaft)
            offset (float, optional)

        Returns:
            mastapy.system_model.connections_and_sockets.CoaxialConnection
        """

        offset = float(offset)
        method_result = self.wrapped.MountOn(shaft.wrapped if shaft else None, offset if offset else 0.0)
        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result) if method_result is not None else None

    def try_mount_on(self, shaft: '_2187.AbstractShaft', offset: Optional['float'] = float('nan')) -> '_2196.ComponentsConnectedResult':
        """ 'TryMountOn' is the original name of this method.

        Args:
            shaft (mastapy.system_model.part_model.AbstractShaft)
            offset (float, optional)

        Returns:
            mastapy.system_model.part_model.ComponentsConnectedResult
        """

        offset = float(offset)
        method_result = self.wrapped.TryMountOn(shaft.wrapped if shaft else None, offset if offset else 0.0)
        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result) if method_result is not None else None



"""_1411.py

Unit
"""


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_UNIT = python_net_import('SMT.MastaAPI.Utility.UnitsAndMeasurements', 'Unit')


__docformat__ = 'restructuredtext en'
__all__ = ('Unit',)


class Unit(_0.APIBase):
    """Unit

    This is a mastapy class.
    """

    TYPE = _UNIT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'Unit.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def html_symbol(self) -> 'str':
        """str: 'HTMLSymbol' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.HTMLSymbol
        return temp

    @property
    def name(self) -> 'str':
        """str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Name
        return temp

    @property
    def offset(self) -> 'float':
        """float: 'Offset' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Offset
        return temp

    @property
    def scale(self) -> 'float':
        """float: 'Scale' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Scale
        return temp

    @property
    def symbol(self) -> 'str':
        """str: 'Symbol' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Symbol
        return temp

    def convert_from_si_unit(self, d: 'float') -> 'float':
        """ 'ConvertFromSIUnit' is the original name of this method.

        Args:
            d (float)

        Returns:
            float
        """

        d = float(d)
        method_result = self.wrapped.ConvertFromSIUnit(d if d else 0.0)
        return method_result

    def convert_to_si_unit(self, d: 'float') -> 'float':
        """ 'ConvertToSIUnit' is the original name of this method.

        Args:
            d (float)

        Returns:
            float
        """

        d = float(d)
        method_result = self.wrapped.ConvertToSIUnit(d if d else 0.0)
        return method_result



"""_1565.py

LegacyChartDefinition
"""


from mastapy.utility.report import _1529
from mastapy._internal.python_net import python_net_import

_LEGACY_CHART_DEFINITION = python_net_import('SMT.MastaAPI.Utility.Report', 'LegacyChartDefinition')


__docformat__ = 'restructuredtext en'
__all__ = ('LegacyChartDefinition',)


class LegacyChartDefinition(_1529.ChartDefinition):
    """LegacyChartDefinition

    This is a mastapy class.
    """

    TYPE = _LEGACY_CHART_DEFINITION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LegacyChartDefinition.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



"""_6781.py

CycloidalDiscAdvancedTimeSteppingAnalysisForModulation
"""


from mastapy.system_model.part_model.cycloidal import _2318
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6582
from mastapy.system_model.analyses_and_results.system_deflections import _2482
from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import _6734
from mastapy._internal.python_net import python_net_import

_CYCLOIDAL_DISC_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation', 'CycloidalDiscAdvancedTimeSteppingAnalysisForModulation')


__docformat__ = 'restructuredtext en'
__all__ = ('CycloidalDiscAdvancedTimeSteppingAnalysisForModulation',)


class CycloidalDiscAdvancedTimeSteppingAnalysisForModulation(_6734.AbstractShaftAdvancedTimeSteppingAnalysisForModulation):
    """CycloidalDiscAdvancedTimeSteppingAnalysisForModulation

    This is a mastapy class.
    """

    TYPE = _CYCLOIDAL_DISC_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CycloidalDiscAdvancedTimeSteppingAnalysisForModulation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2318.CycloidalDisc':
        """CycloidalDisc: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def component_load_case(self) -> '_6582.CycloidalDiscLoadCase':
        """CycloidalDiscLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentLoadCase
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def system_deflection_results(self) -> '_2482.CycloidalDiscSystemDeflection':
        """CycloidalDiscSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SystemDeflectionResults
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""_5312.py

CylindricalGearSetCompoundMultibodyDynamicsAnalysis
"""


from typing import List

from mastapy.system_model.part_model.gears import _2275, _2291
from mastapy._internal import constructor, conversion
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.mbd_analyses import _5163
from mastapy.system_model.analyses_and_results.mbd_analyses.compound import _5310, _5311, _5323
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_SET_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound', 'CylindricalGearSetCompoundMultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearSetCompoundMultibodyDynamicsAnalysis',)


class CylindricalGearSetCompoundMultibodyDynamicsAnalysis(_5323.GearSetCompoundMultibodyDynamicsAnalysis):
    """CylindricalGearSetCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE = _CYLINDRICAL_GEAR_SET_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearSetCompoundMultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2275.CylindricalGearSet':
        """CylindricalGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        if _2275.CylindricalGearSet.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast component_design to CylindricalGearSet. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_design(self) -> '_2275.CylindricalGearSet':
        """CylindricalGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyDesign
        if _2275.CylindricalGearSet.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to CylindricalGearSet. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_5163.CylindricalGearSetMultibodyDynamicsAnalysis]':
        """List[CylindricalGearSetMultibodyDynamicsAnalysis]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCasesReady
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def cylindrical_gears_compound_multibody_dynamics_analysis(self) -> 'List[_5310.CylindricalGearCompoundMultibodyDynamicsAnalysis]':
        """List[CylindricalGearCompoundMultibodyDynamicsAnalysis]: 'CylindricalGearsCompoundMultibodyDynamicsAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.CylindricalGearsCompoundMultibodyDynamicsAnalysis
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def cylindrical_meshes_compound_multibody_dynamics_analysis(self) -> 'List[_5311.CylindricalGearMeshCompoundMultibodyDynamicsAnalysis]':
        """List[CylindricalGearMeshCompoundMultibodyDynamicsAnalysis]: 'CylindricalMeshesCompoundMultibodyDynamicsAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.CylindricalMeshesCompoundMultibodyDynamicsAnalysis
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_5163.CylindricalGearSetMultibodyDynamicsAnalysis]':
        """List[CylindricalGearSetMultibodyDynamicsAnalysis]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCases
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_3226.py

StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft
"""


from typing import List

from mastapy.system_model.part_model.gears import _2295
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import _3096
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft.compound import _3224, _3225, _3137
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_DIFF_GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesOnAShaft.Compound', 'StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft',)


class StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft(_3137.BevelGearSetCompoundSteadyStateSynchronousResponseOnAShaft):
    """StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft

    This is a mastapy class.
    """

    TYPE = _STRAIGHT_BEVEL_DIFF_GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2295.StraightBevelDiffGearSet':
        """StraightBevelDiffGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_design(self) -> '_2295.StraightBevelDiffGearSet':
        """StraightBevelDiffGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_3096.StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft]':
        """List[StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCasesReady
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def straight_bevel_diff_gears_compound_steady_state_synchronous_response_on_a_shaft(self) -> 'List[_3224.StraightBevelDiffGearCompoundSteadyStateSynchronousResponseOnAShaft]':
        """List[StraightBevelDiffGearCompoundSteadyStateSynchronousResponseOnAShaft]: 'StraightBevelDiffGearsCompoundSteadyStateSynchronousResponseOnAShaft' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StraightBevelDiffGearsCompoundSteadyStateSynchronousResponseOnAShaft
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def straight_bevel_diff_meshes_compound_steady_state_synchronous_response_on_a_shaft(self) -> 'List[_3225.StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponseOnAShaft]':
        """List[StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponseOnAShaft]: 'StraightBevelDiffMeshesCompoundSteadyStateSynchronousResponseOnAShaft' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StraightBevelDiffMeshesCompoundSteadyStateSynchronousResponseOnAShaft
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_3096.StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft]':
        """List[StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCases
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2368 import CompoundAnalysis
    from ._2369 import SingleAnalysis
    from ._2370 import AdvancedSystemDeflectionAnalysis
    from ._2371 import AdvancedSystemDeflectionSubAnalysis
    from ._2372 import AdvancedTimeSteppingAnalysisForModulation
    from ._2373 import CompoundParametricStudyToolAnalysis
    from ._2374 import CriticalSpeedAnalysis
    from ._2375 import DynamicAnalysis
    from ._2376 import DynamicModelAtAStiffnessAnalysis
    from ._2377 import DynamicModelForHarmonicAnalysis
    from ._2378 import DynamicModelForModalAnalysis
    from ._2379 import DynamicModelForStabilityAnalysis
    from ._2380 import DynamicModelForSteadyStateSynchronousResponseAnalysis
    from ._2381 import HarmonicAnalysis
    from ._2382 import HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation
    from ._2383 import HarmonicAnalysisOfSingleExcitationAnalysis
    from ._2384 import ModalAnalysis
    from ._2385 import ModalAnalysisAtASpeed
    from ._2386 import ModalAnalysisAtAStiffness
    from ._2387 import ModalAnalysisForHarmonicAnalysis
    from ._2388 import MultibodyDynamicsAnalysis
    from ._2389 import ParametricStudyToolAnalysis
    from ._2390 import PowerFlowAnalysis
    from ._2391 import StabilityAnalysis
    from ._2392 import SteadyStateSynchronousResponseAnalysis
    from ._2393 import SteadyStateSynchronousResponseAtASpeedAnalysis
    from ._2394 import SteadyStateSynchronousResponseOnAShaftAnalysis
    from ._2395 import SystemDeflectionAnalysis
    from ._2396 import TorsionalSystemDeflectionAnalysis
    from ._2397 import AnalysisCaseVariable
    from ._2398 import ConnectionAnalysis
    from ._2399 import Context
    from ._2400 import DesignEntityAnalysis
    from ._2401 import DesignEntityGroupAnalysis
    from ._2402 import DesignEntitySingleContextAnalysis
    from ._2406 import PartAnalysis
    from ._2407 import CompoundAdvancedSystemDeflectionAnalysis
    from ._2408 import CompoundAdvancedSystemDeflectionSubAnalysis
    from ._2409 import CompoundAdvancedTimeSteppingAnalysisForModulation
    from ._2410 import CompoundCriticalSpeedAnalysis
    from ._2411 import CompoundDynamicAnalysis
    from ._2412 import CompoundDynamicModelAtAStiffnessAnalysis
    from ._2413 import CompoundDynamicModelForHarmonicAnalysis
    from ._2414 import CompoundDynamicModelForModalAnalysis
    from ._2415 import CompoundDynamicModelForStabilityAnalysis
    from ._2416 import CompoundDynamicModelForSteadyStateSynchronousResponseAnalysis
    from ._2417 import CompoundHarmonicAnalysis
    from ._2418 import CompoundHarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation
    from ._2419 import CompoundHarmonicAnalysisOfSingleExcitationAnalysis
    from ._2420 import CompoundModalAnalysis
    from ._2421 import CompoundModalAnalysisAtASpeed
    from ._2422 import CompoundModalAnalysisAtAStiffness
    from ._2423 import CompoundModalAnalysisForHarmonicAnalysis
    from ._2424 import CompoundMultibodyDynamicsAnalysis
    from ._2425 import CompoundPowerFlowAnalysis
    from ._2426 import CompoundStabilityAnalysis
    from ._2427 import CompoundSteadyStateSynchronousResponseAnalysis
    from ._2428 import CompoundSteadyStateSynchronousResponseAtASpeedAnalysis
    from ._2429 import CompoundSteadyStateSynchronousResponseOnAShaftAnalysis
    from ._2430 import CompoundSystemDeflectionAnalysis
    from ._2431 import CompoundTorsionalSystemDeflectionAnalysis
    from ._2432 import TESetUpForDynamicAnalysisOptions
    from ._2433 import TimeOptions



"""_4323.py

BevelDifferentialGearMeshModalAnalysis
"""


from mastapy.system_model.connections_and_sockets.gears import _2052
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6547
from mastapy.system_model.analyses_and_results.system_deflections import _2445
from mastapy.system_model.analyses_and_results.modal_analyses import _4328
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_GEAR_MESH_MODAL_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses', 'BevelDifferentialGearMeshModalAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelDifferentialGearMeshModalAnalysis',)


class BevelDifferentialGearMeshModalAnalysis(_4328.BevelGearMeshModalAnalysis):
    """BevelDifferentialGearMeshModalAnalysis

    This is a mastapy class.
    """

    TYPE = _BEVEL_DIFFERENTIAL_GEAR_MESH_MODAL_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelDifferentialGearMeshModalAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self) -> '_2052.BevelDifferentialGearMesh':
        """BevelDifferentialGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def connection_load_case(self) -> '_6547.BevelDifferentialGearMeshLoadCase':
        """BevelDifferentialGearMeshLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ConnectionLoadCase
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def system_deflection_results(self) -> '_2445.BevelDifferentialGearMeshSystemDeflection':
        """BevelDifferentialGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SystemDeflectionResults
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._386 import KlingelnbergConicalMeshSingleFlankRating
    from ._387 import KlingelnbergConicalRateableMesh
    from ._388 import KlingelnbergCycloPalloidConicalGearSingleFlankRating
    from ._389 import KlingelnbergCycloPalloidHypoidGearSingleFlankRating
    from ._390 import KlingelnbergCycloPalloidHypoidMeshSingleFlankRating
    from ._391 import KlingelnbergCycloPalloidSpiralBevelMeshSingleFlankRating



"""_2086.py

CycloidalDiscCentralBearingConnection
"""


from mastapy.system_model.connections_and_sockets import _2020
from mastapy._internal.python_net import python_net_import

_CYCLOIDAL_DISC_CENTRAL_BEARING_CONNECTION = python_net_import('SMT.MastaAPI.SystemModel.ConnectionsAndSockets.Cycloidal', 'CycloidalDiscCentralBearingConnection')


__docformat__ = 'restructuredtext en'
__all__ = ('CycloidalDiscCentralBearingConnection',)


class CycloidalDiscCentralBearingConnection(_2020.CoaxialConnection):
    """CycloidalDiscCentralBearingConnection

    This is a mastapy class.
    """

    TYPE = _CYCLOIDAL_DISC_CENTRAL_BEARING_CONNECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CycloidalDiscCentralBearingConnection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6996 import AbstractAssemblyAdvancedSystemDeflection
    from ._6997 import AbstractShaftAdvancedSystemDeflection
    from ._6998 import AbstractShaftOrHousingAdvancedSystemDeflection
    from ._6999 import AbstractShaftToMountableComponentConnectionAdvancedSystemDeflection
    from ._7000 import AdvancedSystemDeflection
    from ._7001 import AdvancedSystemDeflectionOptions
    from ._7002 import AdvancedSystemDeflectionSubAnalysis
    from ._7003 import AGMAGleasonConicalGearAdvancedSystemDeflection
    from ._7004 import AGMAGleasonConicalGearMeshAdvancedSystemDeflection
    from ._7005 import AGMAGleasonConicalGearSetAdvancedSystemDeflection
    from ._7006 import AssemblyAdvancedSystemDeflection
    from ._7007 import BearingAdvancedSystemDeflection
    from ._7008 import BeltConnectionAdvancedSystemDeflection
    from ._7009 import BeltDriveAdvancedSystemDeflection
    from ._7010 import BevelDifferentialGearAdvancedSystemDeflection
    from ._7011 import BevelDifferentialGearMeshAdvancedSystemDeflection
    from ._7012 import BevelDifferentialGearSetAdvancedSystemDeflection
    from ._7013 import BevelDifferentialPlanetGearAdvancedSystemDeflection
    from ._7014 import BevelDifferentialSunGearAdvancedSystemDeflection
    from ._7015 import BevelGearAdvancedSystemDeflection
    from ._7016 import BevelGearMeshAdvancedSystemDeflection
    from ._7017 import BevelGearSetAdvancedSystemDeflection
    from ._7018 import BoltAdvancedSystemDeflection
    from ._7019 import BoltedJointAdvancedSystemDeflection
    from ._7020 import ClutchAdvancedSystemDeflection
    from ._7021 import ClutchConnectionAdvancedSystemDeflection
    from ._7022 import ClutchHalfAdvancedSystemDeflection
    from ._7023 import CoaxialConnectionAdvancedSystemDeflection
    from ._7024 import ComponentAdvancedSystemDeflection
    from ._7025 import ConceptCouplingAdvancedSystemDeflection
    from ._7026 import ConceptCouplingConnectionAdvancedSystemDeflection
    from ._7027 import ConceptCouplingHalfAdvancedSystemDeflection
    from ._7028 import ConceptGearAdvancedSystemDeflection
    from ._7029 import ConceptGearMeshAdvancedSystemDeflection
    from ._7030 import ConceptGearSetAdvancedSystemDeflection
    from ._7031 import ConicalGearAdvancedSystemDeflection
    from ._7032 import ConicalGearMeshAdvancedSystemDeflection
    from ._7033 import ConicalGearSetAdvancedSystemDeflection
    from ._7034 import ConnectionAdvancedSystemDeflection
    from ._7035 import ConnectorAdvancedSystemDeflection
    from ._7036 import ContactChartPerToothPass
    from ._7037 import CouplingAdvancedSystemDeflection
    from ._7038 import CouplingConnectionAdvancedSystemDeflection
    from ._7039 import CouplingHalfAdvancedSystemDeflection
    from ._7040 import CVTAdvancedSystemDeflection
    from ._7041 import CVTBeltConnectionAdvancedSystemDeflection
    from ._7042 import CVTPulleyAdvancedSystemDeflection
    from ._7043 import CycloidalAssemblyAdvancedSystemDeflection
    from ._7044 import CycloidalDiscAdvancedSystemDeflection
    from ._7045 import CycloidalDiscCentralBearingConnectionAdvancedSystemDeflection
    from ._7046 import CycloidalDiscPlanetaryBearingConnectionAdvancedSystemDeflection
    from ._7047 import CylindricalGearAdvancedSystemDeflection
    from ._7048 import CylindricalGearMeshAdvancedSystemDeflection
    from ._7049 import CylindricalGearSetAdvancedSystemDeflection
    from ._7050 import CylindricalMeshedGearAdvancedSystemDeflection
    from ._7051 import CylindricalPlanetGearAdvancedSystemDeflection
    from ._7052 import DatumAdvancedSystemDeflection
    from ._7053 import ExternalCADModelAdvancedSystemDeflection
    from ._7054 import FaceGearAdvancedSystemDeflection
    from ._7055 import FaceGearMeshAdvancedSystemDeflection
    from ._7056 import FaceGearSetAdvancedSystemDeflection
    from ._7057 import FEPartAdvancedSystemDeflection
    from ._7058 import FlexiblePinAssemblyAdvancedSystemDeflection
    from ._7059 import GearAdvancedSystemDeflection
    from ._7060 import GearMeshAdvancedSystemDeflection
    from ._7061 import GearSetAdvancedSystemDeflection
    from ._7062 import GuideDxfModelAdvancedSystemDeflection
    from ._7063 import HypoidGearAdvancedSystemDeflection
    from ._7064 import HypoidGearMeshAdvancedSystemDeflection
    from ._7065 import HypoidGearSetAdvancedSystemDeflection
    from ._7066 import InterMountableComponentConnectionAdvancedSystemDeflection
    from ._7067 import KlingelnbergCycloPalloidConicalGearAdvancedSystemDeflection
    from ._7068 import KlingelnbergCycloPalloidConicalGearMeshAdvancedSystemDeflection
    from ._7069 import KlingelnbergCycloPalloidConicalGearSetAdvancedSystemDeflection
    from ._7070 import KlingelnbergCycloPalloidHypoidGearAdvancedSystemDeflection
    from ._7071 import KlingelnbergCycloPalloidHypoidGearMeshAdvancedSystemDeflection
    from ._7072 import KlingelnbergCycloPalloidHypoidGearSetAdvancedSystemDeflection
    from ._7073 import KlingelnbergCycloPalloidSpiralBevelGearAdvancedSystemDeflection
    from ._7074 import KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedSystemDeflection
    from ._7075 import KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection
    from ._7076 import UseLtcaInAsdOption
    from ._7077 import MassDiscAdvancedSystemDeflection
    from ._7078 import MeasurementComponentAdvancedSystemDeflection
    from ._7079 import MountableComponentAdvancedSystemDeflection
    from ._7080 import OilSealAdvancedSystemDeflection
    from ._7081 import PartAdvancedSystemDeflection
    from ._7082 import PartToPartShearCouplingAdvancedSystemDeflection
    from ._7083 import PartToPartShearCouplingConnectionAdvancedSystemDeflection
    from ._7084 import PartToPartShearCouplingHalfAdvancedSystemDeflection
    from ._7085 import PlanetaryConnectionAdvancedSystemDeflection
    from ._7086 import PlanetaryGearSetAdvancedSystemDeflection
    from ._7087 import PlanetCarrierAdvancedSystemDeflection
    from ._7088 import PointLoadAdvancedSystemDeflection
    from ._7089 import PowerLoadAdvancedSystemDeflection
    from ._7090 import PulleyAdvancedSystemDeflection
    from ._7091 import RingPinsAdvancedSystemDeflection
    from ._7092 import RingPinsToDiscConnectionAdvancedSystemDeflection
    from ._7093 import RollingRingAdvancedSystemDeflection
    from ._7094 import RollingRingAssemblyAdvancedSystemDeflection
    from ._7095 import RollingRingConnectionAdvancedSystemDeflection
    from ._7096 import RootAssemblyAdvancedSystemDeflection
    from ._7097 import ShaftAdvancedSystemDeflection
    from ._7098 import ShaftHubConnectionAdvancedSystemDeflection
    from ._7099 import ShaftToMountableComponentConnectionAdvancedSystemDeflection
    from ._7100 import SpecialisedAssemblyAdvancedSystemDeflection
    from ._7101 import SpiralBevelGearAdvancedSystemDeflection
    from ._7102 import SpiralBevelGearMeshAdvancedSystemDeflection
    from ._7103 import SpiralBevelGearSetAdvancedSystemDeflection
    from ._7104 import SpringDamperAdvancedSystemDeflection
    from ._7105 import SpringDamperConnectionAdvancedSystemDeflection
    from ._7106 import SpringDamperHalfAdvancedSystemDeflection
    from ._7107 import StraightBevelDiffGearAdvancedSystemDeflection
    from ._7108 import StraightBevelDiffGearMeshAdvancedSystemDeflection
    from ._7109 import StraightBevelDiffGearSetAdvancedSystemDeflection
    from ._7110 import StraightBevelGearAdvancedSystemDeflection
    from ._7111 import StraightBevelGearMeshAdvancedSystemDeflection
    from ._7112 import StraightBevelGearSetAdvancedSystemDeflection
    from ._7113 import StraightBevelPlanetGearAdvancedSystemDeflection
    from ._7114 import StraightBevelSunGearAdvancedSystemDeflection
    from ._7115 import SynchroniserAdvancedSystemDeflection
    from ._7116 import SynchroniserHalfAdvancedSystemDeflection
    from ._7117 import SynchroniserPartAdvancedSystemDeflection
    from ._7118 import SynchroniserSleeveAdvancedSystemDeflection
    from ._7119 import TorqueConverterAdvancedSystemDeflection
    from ._7120 import TorqueConverterConnectionAdvancedSystemDeflection
    from ._7121 import TorqueConverterPumpAdvancedSystemDeflection
    from ._7122 import TorqueConverterTurbineAdvancedSystemDeflection
    from ._7123 import TransmissionErrorToOtherPowerLoad
    from ._7124 import UnbalancedMassAdvancedSystemDeflection
    from ._7125 import VirtualComponentAdvancedSystemDeflection
    from ._7126 import WormGearAdvancedSystemDeflection
    from ._7127 import WormGearMeshAdvancedSystemDeflection
    from ._7128 import WormGearSetAdvancedSystemDeflection
    from ._7129 import ZerolBevelGearAdvancedSystemDeflection
    from ._7130 import ZerolBevelGearMeshAdvancedSystemDeflection
    from ._7131 import ZerolBevelGearSetAdvancedSystemDeflection



"""_1022.py

MicroGeometryConvention
"""


from enum import Enum

from mastapy._internal.python_net import python_net_import

_MICRO_GEOMETRY_CONVENTION = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical', 'MicroGeometryConvention')


__docformat__ = 'restructuredtext en'
__all__ = ('MicroGeometryConvention',)


class MicroGeometryConvention(Enum):
    """MicroGeometryConvention

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _MICRO_GEOMETRY_CONVENTION

    __hash__ = None

    MASTA_DEFAULT_MATERIAL = 0
    LDP = 1
    ISOAGMADINVDIVDE = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


MicroGeometryConvention.__setattr__ = __enum_setattr
MicroGeometryConvention.__delattr__ = __enum_delattr



"""_908.py

DesignConstraintCollectionDatabase
"""


from mastapy.utility.databases import _1604
from mastapy.gears.gear_designs import _909
from mastapy._internal.python_net import python_net_import

_DESIGN_CONSTRAINT_COLLECTION_DATABASE = python_net_import('SMT.MastaAPI.Gears.GearDesigns', 'DesignConstraintCollectionDatabase')


__docformat__ = 'restructuredtext en'
__all__ = ('DesignConstraintCollectionDatabase',)


class DesignConstraintCollectionDatabase(_1604.NamedDatabase['_909.DesignConstraintsCollection']):
    """DesignConstraintCollectionDatabase

    This is a mastapy class.
    """

    TYPE = _DESIGN_CONSTRAINT_COLLECTION_DATABASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'DesignConstraintCollectionDatabase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3248 import AbstractAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3249 import AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed
    from ._3250 import AbstractShaftSteadyStateSynchronousResponseAtASpeed
    from ._3251 import AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3252 import AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3253 import AGMAGleasonConicalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3254 import AGMAGleasonConicalGearSteadyStateSynchronousResponseAtASpeed
    from ._3255 import AssemblySteadyStateSynchronousResponseAtASpeed
    from ._3256 import BearingSteadyStateSynchronousResponseAtASpeed
    from ._3257 import BeltConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3258 import BeltDriveSteadyStateSynchronousResponseAtASpeed
    from ._3259 import BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3260 import BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3261 import BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed
    from ._3262 import BevelDifferentialPlanetGearSteadyStateSynchronousResponseAtASpeed
    from ._3263 import BevelDifferentialSunGearSteadyStateSynchronousResponseAtASpeed
    from ._3264 import BevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3265 import BevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3266 import BevelGearSteadyStateSynchronousResponseAtASpeed
    from ._3267 import BoltedJointSteadyStateSynchronousResponseAtASpeed
    from ._3268 import BoltSteadyStateSynchronousResponseAtASpeed
    from ._3269 import ClutchConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3270 import ClutchHalfSteadyStateSynchronousResponseAtASpeed
    from ._3271 import ClutchSteadyStateSynchronousResponseAtASpeed
    from ._3272 import CoaxialConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3273 import ComponentSteadyStateSynchronousResponseAtASpeed
    from ._3274 import ConceptCouplingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3275 import ConceptCouplingHalfSteadyStateSynchronousResponseAtASpeed
    from ._3276 import ConceptCouplingSteadyStateSynchronousResponseAtASpeed
    from ._3277 import ConceptGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3278 import ConceptGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3279 import ConceptGearSteadyStateSynchronousResponseAtASpeed
    from ._3280 import ConicalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3281 import ConicalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3282 import ConicalGearSteadyStateSynchronousResponseAtASpeed
    from ._3283 import ConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3284 import ConnectorSteadyStateSynchronousResponseAtASpeed
    from ._3285 import CouplingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3286 import CouplingHalfSteadyStateSynchronousResponseAtASpeed
    from ._3287 import CouplingSteadyStateSynchronousResponseAtASpeed
    from ._3288 import CVTBeltConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3289 import CVTPulleySteadyStateSynchronousResponseAtASpeed
    from ._3290 import CVTSteadyStateSynchronousResponseAtASpeed
    from ._3291 import CycloidalAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3292 import CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3293 import CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3294 import CycloidalDiscSteadyStateSynchronousResponseAtASpeed
    from ._3295 import CylindricalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3296 import CylindricalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3297 import CylindricalGearSteadyStateSynchronousResponseAtASpeed
    from ._3298 import CylindricalPlanetGearSteadyStateSynchronousResponseAtASpeed
    from ._3299 import DatumSteadyStateSynchronousResponseAtASpeed
    from ._3300 import ExternalCADModelSteadyStateSynchronousResponseAtASpeed
    from ._3301 import FaceGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3302 import FaceGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3303 import FaceGearSteadyStateSynchronousResponseAtASpeed
    from ._3304 import FEPartSteadyStateSynchronousResponseAtASpeed
    from ._3305 import FlexiblePinAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3306 import GearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3307 import GearSetSteadyStateSynchronousResponseAtASpeed
    from ._3308 import GearSteadyStateSynchronousResponseAtASpeed
    from ._3309 import GuideDxfModelSteadyStateSynchronousResponseAtASpeed
    from ._3310 import HypoidGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3311 import HypoidGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3312 import HypoidGearSteadyStateSynchronousResponseAtASpeed
    from ._3313 import InterMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3314 import KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3315 import KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3316 import KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed
    from ._3317 import KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3318 import KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3319 import KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed
    from ._3320 import KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3321 import KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3322 import KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseAtASpeed
    from ._3323 import MassDiscSteadyStateSynchronousResponseAtASpeed
    from ._3324 import MeasurementComponentSteadyStateSynchronousResponseAtASpeed
    from ._3325 import MountableComponentSteadyStateSynchronousResponseAtASpeed
    from ._3326 import OilSealSteadyStateSynchronousResponseAtASpeed
    from ._3327 import PartSteadyStateSynchronousResponseAtASpeed
    from ._3328 import PartToPartShearCouplingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3329 import PartToPartShearCouplingHalfSteadyStateSynchronousResponseAtASpeed
    from ._3330 import PartToPartShearCouplingSteadyStateSynchronousResponseAtASpeed
    from ._3331 import PlanetaryConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3332 import PlanetaryGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3333 import PlanetCarrierSteadyStateSynchronousResponseAtASpeed
    from ._3334 import PointLoadSteadyStateSynchronousResponseAtASpeed
    from ._3335 import PowerLoadSteadyStateSynchronousResponseAtASpeed
    from ._3336 import PulleySteadyStateSynchronousResponseAtASpeed
    from ._3337 import RingPinsSteadyStateSynchronousResponseAtASpeed
    from ._3338 import RingPinsToDiscConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3339 import RollingRingAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3340 import RollingRingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3341 import RollingRingSteadyStateSynchronousResponseAtASpeed
    from ._3342 import RootAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3343 import ShaftHubConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3344 import ShaftSteadyStateSynchronousResponseAtASpeed
    from ._3345 import ShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3346 import SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3347 import SpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3348 import SpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3349 import SpiralBevelGearSteadyStateSynchronousResponseAtASpeed
    from ._3350 import SpringDamperConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3351 import SpringDamperHalfSteadyStateSynchronousResponseAtASpeed
    from ._3352 import SpringDamperSteadyStateSynchronousResponseAtASpeed
    from ._3353 import SteadyStateSynchronousResponseAtASpeed
    from ._3354 import StraightBevelDiffGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3355 import StraightBevelDiffGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3356 import StraightBevelDiffGearSteadyStateSynchronousResponseAtASpeed
    from ._3357 import StraightBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3358 import StraightBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3359 import StraightBevelGearSteadyStateSynchronousResponseAtASpeed
    from ._3360 import StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed
    from ._3361 import StraightBevelSunGearSteadyStateSynchronousResponseAtASpeed
    from ._3362 import SynchroniserHalfSteadyStateSynchronousResponseAtASpeed
    from ._3363 import SynchroniserPartSteadyStateSynchronousResponseAtASpeed
    from ._3364 import SynchroniserSleeveSteadyStateSynchronousResponseAtASpeed
    from ._3365 import SynchroniserSteadyStateSynchronousResponseAtASpeed
    from ._3366 import TorqueConverterConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3367 import TorqueConverterPumpSteadyStateSynchronousResponseAtASpeed
    from ._3368 import TorqueConverterSteadyStateSynchronousResponseAtASpeed
    from ._3369 import TorqueConverterTurbineSteadyStateSynchronousResponseAtASpeed
    from ._3370 import UnbalancedMassSteadyStateSynchronousResponseAtASpeed
    from ._3371 import VirtualComponentSteadyStateSynchronousResponseAtASpeed
    from ._3372 import WormGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3373 import WormGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3374 import WormGearSteadyStateSynchronousResponseAtASpeed
    from ._3375 import ZerolBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3376 import ZerolBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3377 import ZerolBevelGearSteadyStateSynchronousResponseAtASpeed



"""_4243.py

GearSetCompoundParametricStudyTool
"""


from typing import List

from mastapy.gears.rating import _334
from mastapy._internal import constructor, conversion
from mastapy.gears.rating.worm import _347
from mastapy._internal.cast_exception import CastException
from mastapy.gears.rating.face import _421
from mastapy.gears.rating.cylindrical import _433
from mastapy.gears.rating.conical import _507
from mastapy.gears.rating.concept import _518
from mastapy.system_model.analyses_and_results.parametric_study_tools import _4103
from mastapy.system_model.analyses_and_results.parametric_study_tools.compound import _4281
from mastapy._internal.python_net import python_net_import

_GEAR_SET_COMPOUND_PARAMETRIC_STUDY_TOOL = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools.Compound', 'GearSetCompoundParametricStudyTool')


__docformat__ = 'restructuredtext en'
__all__ = ('GearSetCompoundParametricStudyTool',)


class GearSetCompoundParametricStudyTool(_4281.SpecialisedAssemblyCompoundParametricStudyTool):
    """GearSetCompoundParametricStudyTool

    This is a mastapy class.
    """

    TYPE = _GEAR_SET_COMPOUND_PARAMETRIC_STUDY_TOOL

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearSetCompoundParametricStudyTool.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def gear_set_duty_cycle_results(self) -> '_334.GearSetDutyCycleRating':
        """GearSetDutyCycleRating: 'GearSetDutyCycleResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.GearSetDutyCycleResults
        if _334.GearSetDutyCycleRating.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast gear_set_duty_cycle_results to GearSetDutyCycleRating. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def gear_set_duty_cycle_results_of_type_worm_gear_set_duty_cycle_rating(self) -> '_347.WormGearSetDutyCycleRating':
        """WormGearSetDutyCycleRating: 'GearSetDutyCycleResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.GearSetDutyCycleResults
        if _347.WormGearSetDutyCycleRating.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast gear_set_duty_cycle_results to WormGearSetDutyCycleRating. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def gear_set_duty_cycle_results_of_type_face_gear_set_duty_cycle_rating(self) -> '_421.FaceGearSetDutyCycleRating':
        """FaceGearSetDutyCycleRating: 'GearSetDutyCycleResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.GearSetDutyCycleResults
        if _421.FaceGearSetDutyCycleRating.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast gear_set_duty_cycle_results to FaceGearSetDutyCycleRating. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def gear_set_duty_cycle_results_of_type_cylindrical_gear_set_duty_cycle_rating(self) -> '_433.CylindricalGearSetDutyCycleRating':
        """CylindricalGearSetDutyCycleRating: 'GearSetDutyCycleResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.GearSetDutyCycleResults
        if _433.CylindricalGearSetDutyCycleRating.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast gear_set_duty_cycle_results to CylindricalGearSetDutyCycleRating. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def gear_set_duty_cycle_results_of_type_conical_gear_set_duty_cycle_rating(self) -> '_507.ConicalGearSetDutyCycleRating':
        """ConicalGearSetDutyCycleRating: 'GearSetDutyCycleResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.GearSetDutyCycleResults
        if _507.ConicalGearSetDutyCycleRating.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast gear_set_duty_cycle_results to ConicalGearSetDutyCycleRating. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def gear_set_duty_cycle_results_of_type_concept_gear_set_duty_cycle_rating(self) -> '_518.ConceptGearSetDutyCycleRating':
        """ConceptGearSetDutyCycleRating: 'GearSetDutyCycleResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.GearSetDutyCycleResults
        if _518.ConceptGearSetDutyCycleRating.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast gear_set_duty_cycle_results to ConceptGearSetDutyCycleRating. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_analysis_cases(self) -> 'List[_4103.GearSetParametricStudyTool]':
        """List[GearSetParametricStudyTool]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCases
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_4103.GearSetParametricStudyTool]':
        """List[GearSetParametricStudyTool]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCasesReady
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._5111 import AbstractAssemblyMultibodyDynamicsAnalysis
    from ._5112 import AbstractShaftMultibodyDynamicsAnalysis
    from ._5113 import AbstractShaftOrHousingMultibodyDynamicsAnalysis
    from ._5114 import AbstractShaftToMountableComponentConnectionMultibodyDynamicsAnalysis
    from ._5115 import AGMAGleasonConicalGearMeshMultibodyDynamicsAnalysis
    from ._5116 import AGMAGleasonConicalGearMultibodyDynamicsAnalysis
    from ._5117 import AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis
    from ._5118 import AnalysisTypes
    from ._5119 import AssemblyMultibodyDynamicsAnalysis
    from ._5120 import BearingMultibodyDynamicsAnalysis
    from ._5121 import BearingStiffnessModel
    from ._5122 import BeltConnectionMultibodyDynamicsAnalysis
    from ._5123 import BeltDriveMultibodyDynamicsAnalysis
    from ._5124 import BevelDifferentialGearMeshMultibodyDynamicsAnalysis
    from ._5125 import BevelDifferentialGearMultibodyDynamicsAnalysis
    from ._5126 import BevelDifferentialGearSetMultibodyDynamicsAnalysis
    from ._5127 import BevelDifferentialPlanetGearMultibodyDynamicsAnalysis
    from ._5128 import BevelDifferentialSunGearMultibodyDynamicsAnalysis
    from ._5129 import BevelGearMeshMultibodyDynamicsAnalysis
    from ._5130 import BevelGearMultibodyDynamicsAnalysis
    from ._5131 import BevelGearSetMultibodyDynamicsAnalysis
    from ._5132 import BoltedJointMultibodyDynamicsAnalysis
    from ._5133 import BoltMultibodyDynamicsAnalysis
    from ._5134 import ClutchConnectionMultibodyDynamicsAnalysis
    from ._5135 import ClutchHalfMultibodyDynamicsAnalysis
    from ._5136 import ClutchMultibodyDynamicsAnalysis
    from ._5137 import ClutchSpringType
    from ._5138 import CoaxialConnectionMultibodyDynamicsAnalysis
    from ._5139 import ComponentMultibodyDynamicsAnalysis
    from ._5140 import ConceptCouplingConnectionMultibodyDynamicsAnalysis
    from ._5141 import ConceptCouplingHalfMultibodyDynamicsAnalysis
    from ._5142 import ConceptCouplingMultibodyDynamicsAnalysis
    from ._5143 import ConceptGearMeshMultibodyDynamicsAnalysis
    from ._5144 import ConceptGearMultibodyDynamicsAnalysis
    from ._5145 import ConceptGearSetMultibodyDynamicsAnalysis
    from ._5146 import ConicalGearMeshMultibodyDynamicsAnalysis
    from ._5147 import ConicalGearMultibodyDynamicsAnalysis
    from ._5148 import ConicalGearSetMultibodyDynamicsAnalysis
    from ._5149 import ConnectionMultibodyDynamicsAnalysis
    from ._5150 import ConnectorMultibodyDynamicsAnalysis
    from ._5151 import CouplingConnectionMultibodyDynamicsAnalysis
    from ._5152 import CouplingHalfMultibodyDynamicsAnalysis
    from ._5153 import CouplingMultibodyDynamicsAnalysis
    from ._5154 import CVTBeltConnectionMultibodyDynamicsAnalysis
    from ._5155 import CVTMultibodyDynamicsAnalysis
    from ._5156 import CVTPulleyMultibodyDynamicsAnalysis
    from ._5157 import CycloidalAssemblyMultibodyDynamicsAnalysis
    from ._5158 import CycloidalDiscCentralBearingConnectionMultibodyDynamicsAnalysis
    from ._5159 import CycloidalDiscMultibodyDynamicsAnalysis
    from ._5160 import CycloidalDiscPlanetaryBearingConnectionMultibodyDynamicsAnalysis
    from ._5161 import CylindricalGearMeshMultibodyDynamicsAnalysis
    from ._5162 import CylindricalGearMultibodyDynamicsAnalysis
    from ._5163 import CylindricalGearSetMultibodyDynamicsAnalysis
    from ._5164 import CylindricalPlanetGearMultibodyDynamicsAnalysis
    from ._5165 import DatumMultibodyDynamicsAnalysis
    from ._5166 import ExternalCADModelMultibodyDynamicsAnalysis
    from ._5167 import FaceGearMeshMultibodyDynamicsAnalysis
    from ._5168 import FaceGearMultibodyDynamicsAnalysis
    from ._5169 import FaceGearSetMultibodyDynamicsAnalysis
    from ._5170 import FEPartMultibodyDynamicsAnalysis
    from ._5171 import FlexiblePinAssemblyMultibodyDynamicsAnalysis
    from ._5172 import GearMeshMultibodyDynamicsAnalysis
    from ._5173 import GearMeshStiffnessModel
    from ._5174 import GearMultibodyDynamicsAnalysis
    from ._5175 import GearSetMultibodyDynamicsAnalysis
    from ._5176 import GuideDxfModelMultibodyDynamicsAnalysis
    from ._5177 import HypoidGearMeshMultibodyDynamicsAnalysis
    from ._5178 import HypoidGearMultibodyDynamicsAnalysis
    from ._5179 import HypoidGearSetMultibodyDynamicsAnalysis
    from ._5180 import InertiaAdjustedLoadCasePeriodMethod
    from ._5181 import InertiaAdjustedLoadCaseResultsToCreate
    from ._5182 import InputSignalFilterLevel
    from ._5183 import InputVelocityForRunUpProcessingType
    from ._5184 import InterMountableComponentConnectionMultibodyDynamicsAnalysis
    from ._5185 import KlingelnbergCycloPalloidConicalGearMeshMultibodyDynamicsAnalysis
    from ._5186 import KlingelnbergCycloPalloidConicalGearMultibodyDynamicsAnalysis
    from ._5187 import KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis
    from ._5188 import KlingelnbergCycloPalloidHypoidGearMeshMultibodyDynamicsAnalysis
    from ._5189 import KlingelnbergCycloPalloidHypoidGearMultibodyDynamicsAnalysis
    from ._5190 import KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis
    from ._5191 import KlingelnbergCycloPalloidSpiralBevelGearMeshMultibodyDynamicsAnalysis
    from ._5192 import KlingelnbergCycloPalloidSpiralBevelGearMultibodyDynamicsAnalysis
    from ._5193 import KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis
    from ._5194 import MassDiscMultibodyDynamicsAnalysis
    from ._5195 import MBDAnalysisDrawStyle
    from ._5196 import MBDAnalysisOptions
    from ._5197 import MBDRunUpAnalysisOptions
    from ._5198 import MeasurementComponentMultibodyDynamicsAnalysis
    from ._5199 import MountableComponentMultibodyDynamicsAnalysis
    from ._2388 import MultibodyDynamicsAnalysis
    from ._5200 import OilSealMultibodyDynamicsAnalysis
    from ._5201 import PartMultibodyDynamicsAnalysis
    from ._5202 import PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis
    from ._5203 import PartToPartShearCouplingHalfMultibodyDynamicsAnalysis
    from ._5204 import PartToPartShearCouplingMultibodyDynamicsAnalysis
    from ._5205 import PlanetaryConnectionMultibodyDynamicsAnalysis
    from ._5206 import PlanetaryGearSetMultibodyDynamicsAnalysis
    from ._5207 import PlanetCarrierMultibodyDynamicsAnalysis
    from ._5208 import PointLoadMultibodyDynamicsAnalysis
    from ._5209 import PowerLoadMultibodyDynamicsAnalysis
    from ._5210 import PulleyMultibodyDynamicsAnalysis
    from ._5211 import RingPinsMultibodyDynamicsAnalysis
    from ._5212 import RingPinsToDiscConnectionMultibodyDynamicsAnalysis
    from ._5213 import RollingRingAssemblyMultibodyDynamicsAnalysis
    from ._5214 import RollingRingConnectionMultibodyDynamicsAnalysis
    from ._5215 import RollingRingMultibodyDynamicsAnalysis
    from ._5216 import RootAssemblyMultibodyDynamicsAnalysis
    from ._5217 import RunUpDrivingMode
    from ._5218 import ShaftAndHousingFlexibilityOption
    from ._5219 import ShaftHubConnectionMultibodyDynamicsAnalysis
    from ._5220 import ShaftMultibodyDynamicsAnalysis
    from ._5221 import ShaftToMountableComponentConnectionMultibodyDynamicsAnalysis
    from ._5222 import ShapeOfInitialAccelerationPeriodForRunUp
    from ._5223 import SpecialisedAssemblyMultibodyDynamicsAnalysis
    from ._5224 import SpiralBevelGearMeshMultibodyDynamicsAnalysis
    from ._5225 import SpiralBevelGearMultibodyDynamicsAnalysis
    from ._5226 import SpiralBevelGearSetMultibodyDynamicsAnalysis
    from ._5227 import SpringDamperConnectionMultibodyDynamicsAnalysis
    from ._5228 import SpringDamperHalfMultibodyDynamicsAnalysis
    from ._5229 import SpringDamperMultibodyDynamicsAnalysis
    from ._5230 import StraightBevelDiffGearMeshMultibodyDynamicsAnalysis
    from ._5231 import StraightBevelDiffGearMultibodyDynamicsAnalysis
    from ._5232 import StraightBevelDiffGearSetMultibodyDynamicsAnalysis
    from ._5233 import StraightBevelGearMeshMultibodyDynamicsAnalysis
    from ._5234 import StraightBevelGearMultibodyDynamicsAnalysis
    from ._5235 import StraightBevelGearSetMultibodyDynamicsAnalysis
    from ._5236 import StraightBevelPlanetGearMultibodyDynamicsAnalysis
    from ._5237 import StraightBevelSunGearMultibodyDynamicsAnalysis
    from ._5238 import SynchroniserHalfMultibodyDynamicsAnalysis
    from ._5239 import SynchroniserMultibodyDynamicsAnalysis
    from ._5240 import SynchroniserPartMultibodyDynamicsAnalysis
    from ._5241 import SynchroniserSleeveMultibodyDynamicsAnalysis
    from ._5242 import TorqueConverterConnectionMultibodyDynamicsAnalysis
    from ._5243 import TorqueConverterLockupRule
    from ._5244 import TorqueConverterMultibodyDynamicsAnalysis
    from ._5245 import TorqueConverterPumpMultibodyDynamicsAnalysis
    from ._5246 import TorqueConverterStatus
    from ._5247 import TorqueConverterTurbineMultibodyDynamicsAnalysis
    from ._5248 import UnbalancedMassMultibodyDynamicsAnalysis
    from ._5249 import VirtualComponentMultibodyDynamicsAnalysis
    from ._5250 import WheelSlipType
    from ._5251 import WormGearMeshMultibodyDynamicsAnalysis
    from ._5252 import WormGearMultibodyDynamicsAnalysis
    from ._5253 import WormGearSetMultibodyDynamicsAnalysis
    from ._5254 import ZerolBevelGearMeshMultibodyDynamicsAnalysis
    from ._5255 import ZerolBevelGearMultibodyDynamicsAnalysis
    from ._5256 import ZerolBevelGearSetMultibodyDynamicsAnalysis



"""_2454.py

BoltSystemDeflection
"""


from mastapy.system_model.part_model import _2193
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6555
from mastapy.system_model.analyses_and_results.power_flows import _3794
from mastapy.system_model.analyses_and_results.system_deflections import _2459
from mastapy._internal.python_net import python_net_import

_BOLT_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections', 'BoltSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('BoltSystemDeflection',)


class BoltSystemDeflection(_2459.ComponentSystemDeflection):
    """BoltSystemDeflection

    This is a mastapy class.
    """

    TYPE = _BOLT_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BoltSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2193.Bolt':
        """Bolt: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def component_load_case(self) -> '_6555.BoltLoadCase':
        """BoltLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentLoadCase
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def power_flow_results(self) -> '_3794.BoltPowerFlow':
        """BoltPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PowerFlowResults
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None



"""_588.py

CylindricalMeshManufacturingConfig
"""


from typing import List

from mastapy.gears.manufacturing.cylindrical.cutter_simulation import _697, _700, _701
from mastapy._internal import constructor, conversion
from mastapy.gears.analysis import _1177
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_MESH_MANUFACTURING_CONFIG = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical', 'CylindricalMeshManufacturingConfig')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalMeshManufacturingConfig',)


class CylindricalMeshManufacturingConfig(_1177.GearMeshImplementationDetail):
    """CylindricalMeshManufacturingConfig

    This is a mastapy class.
    """

    TYPE = _CYLINDRICAL_MESH_MANUFACTURING_CONFIG

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalMeshManufacturingConfig.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def gear_a_as_manufactured(self) -> 'List[_697.CutterSimulationCalc]':
        """List[CutterSimulationCalc]: 'GearAAsManufactured' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.GearAAsManufactured
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def gear_b_as_manufactured(self) -> 'List[_697.CutterSimulationCalc]':
        """List[CutterSimulationCalc]: 'GearBAsManufactured' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.GearBAsManufactured
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def meshed_gear_a_as_manufactured(self) -> 'List[_700.CylindricalManufacturedRealGearInMesh]':
        """List[CylindricalManufacturedRealGearInMesh]: 'MeshedGearAAsManufactured' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MeshedGearAAsManufactured
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def meshed_gear_a_as_manufactured_virtual(self) -> 'List[_701.CylindricalManufacturedVirtualGearInMesh]':
        """List[CylindricalManufacturedVirtualGearInMesh]: 'MeshedGearAAsManufacturedVirtual' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MeshedGearAAsManufacturedVirtual
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def meshed_gear_b_as_manufactured(self) -> 'List[_700.CylindricalManufacturedRealGearInMesh]':
        """List[CylindricalManufacturedRealGearInMesh]: 'MeshedGearBAsManufactured' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MeshedGearBAsManufactured
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def meshed_gear_b_as_manufactured_virtual(self) -> 'List[_701.CylindricalManufacturedVirtualGearInMesh]':
        """List[CylindricalManufacturedVirtualGearInMesh]: 'MeshedGearBAsManufacturedVirtual' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MeshedGearBAsManufacturedVirtual
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_197.py

NodeDetailsForFEModel
"""


from typing import List

from mastapy._internal import constructor, conversion
from mastapy._math.vector_3d import Vector3D
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_NODE_DETAILS_FOR_FE_MODEL = python_net_import('SMT.MastaAPI.NodalAnalysis.DevToolsAnalyses.FullFEReporting', 'NodeDetailsForFEModel')


__docformat__ = 'restructuredtext en'
__all__ = ('NodeDetailsForFEModel',)


class NodeDetailsForFEModel(_0.APIBase):
    """NodeDetailsForFEModel

    This is a mastapy class.
    """

    TYPE = _NODE_DETAILS_FOR_FE_MODEL

    __hash__ = None

    def __init__(self, instance_to_wrap: 'NodeDetailsForFEModel.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def external_ids(self) -> 'List[int]':
        """List[int]: 'ExternalIDs' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ExternalIDs
        value = conversion.pn_to_mp_objects_in_list(temp, int)
        return value

    @property
    def node_positions(self) -> 'List[Vector3D]':
        """List[Vector3D]: 'NodePositions' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NodePositions
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_5916.py

ExternalCADModelCompoundHarmonicAnalysisOfSingleExcitation
"""


from typing import List

from mastapy.system_model.part_model import _2202
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation import _5786
from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation.compound import _5889
from mastapy._internal.python_net import python_net_import

_EXTERNAL_CAD_MODEL_COMPOUND_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalysesSingleExcitation.Compound', 'ExternalCADModelCompoundHarmonicAnalysisOfSingleExcitation')


__docformat__ = 'restructuredtext en'
__all__ = ('ExternalCADModelCompoundHarmonicAnalysisOfSingleExcitation',)


class ExternalCADModelCompoundHarmonicAnalysisOfSingleExcitation(_5889.ComponentCompoundHarmonicAnalysisOfSingleExcitation):
    """ExternalCADModelCompoundHarmonicAnalysisOfSingleExcitation

    This is a mastapy class.
    """

    TYPE = _EXTERNAL_CAD_MODEL_COMPOUND_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ExternalCADModelCompoundHarmonicAnalysisOfSingleExcitation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2202.ExternalCADModel':
        """ExternalCADModel: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def component_analysis_cases_ready(self) -> 'List[_5786.ExternalCADModelHarmonicAnalysisOfSingleExcitation]':
        """List[ExternalCADModelHarmonicAnalysisOfSingleExcitation]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentAnalysisCasesReady
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def component_analysis_cases(self) -> 'List[_5786.ExternalCADModelHarmonicAnalysisOfSingleExcitation]':
        """List[ExternalCADModelHarmonicAnalysisOfSingleExcitation]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentAnalysisCases
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_79.py

ResultLoggingFrequency
"""


from enum import Enum

from mastapy._internal.python_net import python_net_import

_RESULT_LOGGING_FREQUENCY = python_net_import('SMT.MastaAPI.NodalAnalysis', 'ResultLoggingFrequency')


__docformat__ = 'restructuredtext en'
__all__ = ('ResultLoggingFrequency',)


class ResultLoggingFrequency(Enum):
    """ResultLoggingFrequency

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _RESULT_LOGGING_FREQUENCY

    __hash__ = None

    ALL = 0
    IGNORE_SMALL_STEPS = 1
    NONE = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


ResultLoggingFrequency.__setattr__ = __enum_setattr
ResultLoggingFrequency.__delattr__ = __enum_delattr



"""_486.py

ISO6336AbstractMetalGearSingleFlankRating
"""


from mastapy._internal import constructor
from mastapy.gears.rating.cylindrical.iso6336 import _484
from mastapy._internal.python_net import python_net_import

_ISO6336_ABSTRACT_METAL_GEAR_SINGLE_FLANK_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.Cylindrical.ISO6336', 'ISO6336AbstractMetalGearSingleFlankRating')


__docformat__ = 'restructuredtext en'
__all__ = ('ISO6336AbstractMetalGearSingleFlankRating',)


class ISO6336AbstractMetalGearSingleFlankRating(_484.ISO6336AbstractGearSingleFlankRating):
    """ISO6336AbstractMetalGearSingleFlankRating

    This is a mastapy class.
    """

    TYPE = _ISO6336_ABSTRACT_METAL_GEAR_SINGLE_FLANK_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ISO6336AbstractMetalGearSingleFlankRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def addendum_contact_ratio(self) -> 'float':
        """float: 'AddendumContactRatio' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AddendumContactRatio
        return temp

    @property
    def base_pitch_deviation(self) -> 'float':
        """float: 'BasePitchDeviation' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.BasePitchDeviation
        return temp

    @property
    def life_factor_for_bending_stress(self) -> 'float':
        """float: 'LifeFactorForBendingStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LifeFactorForBendingStress
        return temp

    @property
    def life_factor_for_contact_stress(self) -> 'float':
        """float: 'LifeFactorForContactStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LifeFactorForContactStress
        return temp

    @property
    def life_factor_for_reference_bending_stress(self) -> 'float':
        """float: 'LifeFactorForReferenceBendingStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LifeFactorForReferenceBendingStress
        return temp

    @property
    def life_factor_for_reference_contact_stress(self) -> 'float':
        """float: 'LifeFactorForReferenceContactStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LifeFactorForReferenceContactStress
        return temp

    @property
    def life_factor_for_static_bending_stress(self) -> 'float':
        """float: 'LifeFactorForStaticBendingStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LifeFactorForStaticBendingStress
        return temp

    @property
    def life_factor_for_static_contact_stress(self) -> 'float':
        """float: 'LifeFactorForStaticContactStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LifeFactorForStaticContactStress
        return temp

    @property
    def lubricant_factor(self) -> 'float':
        """float: 'LubricantFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LubricantFactor
        return temp

    @property
    def lubricant_factor_for_reference_stress(self) -> 'float':
        """float: 'LubricantFactorForReferenceStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LubricantFactorForReferenceStress
        return temp

    @property
    def lubricant_factor_for_static_stress(self) -> 'float':
        """float: 'LubricantFactorForStaticStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LubricantFactorForStaticStress
        return temp

    @property
    def moment_of_inertia_per_unit_face_width(self) -> 'float':
        """float: 'MomentOfInertiaPerUnitFaceWidth' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MomentOfInertiaPerUnitFaceWidth
        return temp

    @property
    def profile_form_deviation(self) -> 'float':
        """float: 'ProfileFormDeviation' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ProfileFormDeviation
        return temp

    @property
    def relative_individual_gear_mass_per_unit_face_width_referenced_to_line_of_action(self) -> 'float':
        """float: 'RelativeIndividualGearMassPerUnitFaceWidthReferencedToLineOfAction' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RelativeIndividualGearMassPerUnitFaceWidthReferencedToLineOfAction
        return temp

    @property
    def relative_notch_sensitivity_factor(self) -> 'float':
        """float: 'RelativeNotchSensitivityFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RelativeNotchSensitivityFactor
        return temp

    @property
    def relative_notch_sensitivity_factor_for_reference_stress(self) -> 'float':
        """float: 'RelativeNotchSensitivityFactorForReferenceStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RelativeNotchSensitivityFactorForReferenceStress
        return temp

    @property
    def relative_notch_sensitivity_factor_for_static_stress(self) -> 'float':
        """float: 'RelativeNotchSensitivityFactorForStaticStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RelativeNotchSensitivityFactorForStaticStress
        return temp

    @property
    def relative_surface_factor(self) -> 'float':
        """float: 'RelativeSurfaceFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RelativeSurfaceFactor
        return temp

    @property
    def relative_surface_factor_for_reference_stress(self) -> 'float':
        """float: 'RelativeSurfaceFactorForReferenceStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RelativeSurfaceFactorForReferenceStress
        return temp

    @property
    def relative_surface_factor_for_static_stress(self) -> 'float':
        """float: 'RelativeSurfaceFactorForStaticStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RelativeSurfaceFactorForStaticStress
        return temp

    @property
    def roughness_factor(self) -> 'float':
        """float: 'RoughnessFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RoughnessFactor
        return temp

    @property
    def roughness_factor_for_reference_stress(self) -> 'float':
        """float: 'RoughnessFactorForReferenceStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RoughnessFactorForReferenceStress
        return temp

    @property
    def roughness_factor_for_static_stress(self) -> 'float':
        """float: 'RoughnessFactorForStaticStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.RoughnessFactorForStaticStress
        return temp

    @property
    def shot_peening_bending_stress_benefit(self) -> 'float':
        """float: 'ShotPeeningBendingStressBenefit' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ShotPeeningBendingStressBenefit
        return temp

    @property
    def single_pair_tooth_contact_factor(self) -> 'float':
        """float: 'SinglePairToothContactFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SinglePairToothContactFactor
        return temp

    @property
    def size_factor(self) -> 'float':
        """float: 'SizeFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SizeFactor
        return temp

    @property
    def size_factor_tooth_root(self) -> 'float':
        """float: 'SizeFactorToothRoot' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SizeFactorToothRoot
        return temp

    @property
    def size_factor_for_reference_bending_stress(self) -> 'float':
        """float: 'SizeFactorForReferenceBendingStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SizeFactorForReferenceBendingStress
        return temp

    @property
    def size_factor_for_reference_contact_stress(self) -> 'float':
        """float: 'SizeFactorForReferenceContactStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SizeFactorForReferenceContactStress
        return temp

    @property
    def size_factor_for_static_stress(self) -> 'float':
        """float: 'SizeFactorForStaticStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SizeFactorForStaticStress
        return temp

    @property
    def static_size_factor_tooth_root(self) -> 'float':
        """float: 'StaticSizeFactorToothRoot' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.StaticSizeFactorToothRoot
        return temp

    @property
    def velocity_factor(self) -> 'float':
        """float: 'VelocityFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.VelocityFactor
        return temp

    @property
    def velocity_factor_for_reference_stress(self) -> 'float':
        """float: 'VelocityFactorForReferenceStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.VelocityFactorForReferenceStress
        return temp

    @property
    def velocity_factor_for_static_stress(self) -> 'float':
        """float: 'VelocityFactorForStaticStress' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.VelocityFactorForStaticStress
        return temp

    @property
    def work_hardening_factor(self) -> 'float':
        """float: 'WorkHardeningFactor' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.WorkHardeningFactor
        return temp



"""_2342.py

RigidConnectorToothLocation
"""


from typing import List

from mastapy._internal import constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_RIGID_CONNECTOR_TOOTH_LOCATION = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Couplings', 'RigidConnectorToothLocation')


__docformat__ = 'restructuredtext en'
__all__ = ('RigidConnectorToothLocation',)


class RigidConnectorToothLocation(_0.APIBase):
    """RigidConnectorToothLocation

    This is a mastapy class.
    """

    TYPE = _RIGID_CONNECTOR_TOOTH_LOCATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RigidConnectorToothLocation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def centre_angle(self) -> 'float':
        """float: 'CentreAngle' is the original name of this property."""

        temp = self.wrapped.CentreAngle
        return temp

    @centre_angle.setter
    def centre_angle(self, value: 'float'):
        self.wrapped.CentreAngle = float(value) if value else 0.0

    @property
    def end_angle(self) -> 'float':
        """float: 'EndAngle' is the original name of this property."""

        temp = self.wrapped.EndAngle
        return temp

    @end_angle.setter
    def end_angle(self, value: 'float'):
        self.wrapped.EndAngle = float(value) if value else 0.0

    @property
    def extent(self) -> 'float':
        """float: 'Extent' is the original name of this property."""

        temp = self.wrapped.Extent
        return temp

    @extent.setter
    def extent(self, value: 'float'):
        self.wrapped.Extent = float(value) if value else 0.0

    @property
    def id(self) -> 'int':
        """int: 'ID' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ID
        return temp

    @property
    def major_diameter_error(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'MajorDiameterError' is the original name of this property."""

        temp = self.wrapped.MajorDiameterError
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @major_diameter_error.setter
    def major_diameter_error(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.MajorDiameterError = value

    @property
    def major_diameter_radial_clearance(self) -> 'float':
        """float: 'MajorDiameterRadialClearance' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MajorDiameterRadialClearance
        return temp

    @property
    def name(self) -> 'str':
        """str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Name
        return temp

    @property
    def normal_clearance_left_flank(self) -> 'float':
        """float: 'NormalClearanceLeftFlank' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NormalClearanceLeftFlank
        return temp

    @property
    def normal_clearance_right_flank(self) -> 'float':
        """float: 'NormalClearanceRightFlank' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NormalClearanceRightFlank
        return temp

    @property
    def pitch_error_left_flank(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'PitchErrorLeftFlank' is the original name of this property."""

        temp = self.wrapped.PitchErrorLeftFlank
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @pitch_error_left_flank.setter
    def pitch_error_left_flank(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.PitchErrorLeftFlank = value

    @property
    def pitch_error_right_flank(self) -> 'overridable.Overridable_float':
        """overridable.Overridable_float: 'PitchErrorRightFlank' is the original name of this property."""

        temp = self.wrapped.PitchErrorRightFlank
        return constructor.new_from_mastapy_type(overridable.Overridable_float)(temp) if temp is not None else None

    @pitch_error_right_flank.setter
    def pitch_error_right_flank(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value is not None else 0.0, is_overridden)
        self.wrapped.PitchErrorRightFlank = value

    @property
    def start_angle(self) -> 'float':
        """float: 'StartAngle' is the original name of this property."""

        temp = self.wrapped.StartAngle
        return temp

    @start_angle.setter
    def start_angle(self, value: 'float'):
        self.wrapped.StartAngle = float(value) if value else 0.0

    @property
    def report_names(self) -> 'List[str]':
        """List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ReportNames
        value = conversion.pn_to_mp_objects_in_list(temp, str)
        return value

    def output_default_report_to(self, file_path: 'str'):
        """ 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else '')

    def get_default_report_with_encoded_images(self) -> 'str':
        """ 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        """ 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else '')

    def output_active_report_as_text_to(self, file_path: 'str'):
        """ 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else '')

    def get_active_report_with_encoded_images(self) -> 'str':
        """ 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else '', file_path if file_path else '')

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        """ 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        """

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else '')
        return method_result



"""_1739.py

LoadedAbstractSphericalRollerBearingStripLoadResults
"""


from mastapy.bearings.bearing_results.rolling import _1789
from mastapy._internal.python_net import python_net_import

_LOADED_ABSTRACT_SPHERICAL_ROLLER_BEARING_STRIP_LOAD_RESULTS = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'LoadedAbstractSphericalRollerBearingStripLoadResults')


__docformat__ = 'restructuredtext en'
__all__ = ('LoadedAbstractSphericalRollerBearingStripLoadResults',)


class LoadedAbstractSphericalRollerBearingStripLoadResults(_1789.LoadedRollerStripLoadResults):
    """LoadedAbstractSphericalRollerBearingStripLoadResults

    This is a mastapy class.
    """

    TYPE = _LOADED_ABSTRACT_SPHERICAL_ROLLER_BEARING_STRIP_LOAD_RESULTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LoadedAbstractSphericalRollerBearingStripLoadResults.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()
